@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #******************************************************************************
-#  $Id: pct2rgb.py 18194 2009-12-06 20:07:45Z rouault $
+#  $Id: pct2rgb.py 27044 2014-03-16 23:41:27Z rouault $
 # 
 #  Name:     pct2rgb
 #  Project:  GDAL Python Interface
@@ -9,6 +9,7 @@
 # 
 #******************************************************************************
 #  Copyright (c) 2001, Frank Warmerdam
+#  Copyright (c) 2009-2010, Even Rouault <even dot rouault at mines-paris dot org>
 # 
 #  Permission is hereby granted, free of charge, to any person obtaining a
 #  copy of this software and associated documentation files (the "Software"),
@@ -31,10 +32,14 @@
 
 try:
     from osgeo import gdal
-    gdal.TermProgress = gdal.TermProgress_nocb
 except ImportError:
     import gdal
 
+try:
+    progress = gdal.TermProgress_nocb
+except:
+    progress = gdal.TermProgress
+
 try:
     import numpy as Numeric
     Numeric.arrayrange = Numeric.arange
@@ -46,7 +51,7 @@ import sys
 import os.path
 
 def Usage():
-    print('Usage: pct2rgb.py [-of format] [-b <band>] source_file dest_file')
+    print('Usage: pct2rgb.py [-of format] [-b <band>] [-rgba] source_file dest_file')
     sys.exit(1)
 
 # =============================================================================
@@ -93,13 +98,13 @@ while i < len(argv):
 
 if dst_filename is None:
     Usage()
-    
+
 # ----------------------------------------------------------------------------
 # Open source file
 
 src_ds = gdal.Open( src_filename )
 if src_ds is None:
-    print('Unable to open ', src_filename)
+    print('Unable to open %s ' % src_filename)
     sys.exit(1)
 
 src_band = src_ds.GetRasterBand(band_number)
@@ -115,15 +120,16 @@ if dst_driver is None:
 # ----------------------------------------------------------------------------
 # Build color table.
 
-lookup = [ Numeric.arrayrange(256), 
-           Numeric.arrayrange(256), 
-           Numeric.arrayrange(256), 
-           Numeric.ones(256)*255 ]
-
 ct = src_band.GetRasterColorTable()
 
+ct_size = max(256, ct.GetCount())
+lookup = [Numeric.arrayrange(ct_size),
+          Numeric.arrayrange(ct_size),
+          Numeric.arrayrange(ct_size),
+          Numeric.ones(ct_size) * 255]
+
 if ct is not None:
-    for i in range(min(256,ct.GetCount())):
+    for i in range(ct_size):
         entry = ct.GetColorEntry(i)
         for c in range(4):
             lookup[c][i] = entry[c]
@@ -151,9 +157,9 @@ if src_ds.GetGCPCount() > 0:
     tif_ds.SetGCPs( src_ds.GetGCPs(), src_ds.GetGCPProjection() )
 
 # ----------------------------------------------------------------------------
-# Do the processing one scanline at a time. 
+# Do the processing one scanline at a time.
 
-gdal.TermProgress( 0.0 )
+progress( 0.0 )
 for iY in range(src_ds.RasterYSize):
     src_data = src_band.ReadAsArray(0,iY,src_ds.RasterXSize,1)
 
@@ -163,8 +169,8 @@ for iY in range(src_ds.RasterYSize):
         dst_data = Numeric.take(band_lookup,src_data)
         tif_ds.GetRasterBand(iBand+1).WriteArray(dst_data,0,iY)
 
-    gdal.TermProgress( (iY+1.0) / src_ds.RasterYSize )
-    
+    progress( (iY+1.0) / src_ds.RasterYSize )
+
 
 tif_ds = None
 
